@@ -33,6 +33,4 @@ Factories that create an eigensolver based on a qubit transformation.
 from .eigensolver_factory import EigensolverFactory
 from .numpy_eigensolver_factory import NumPyEigensolverFactory
 
-__all__ = ['EigensolverFactory',
-           'NumPyEigensolverFactory'
-           ]
+__all__ = ["EigensolverFactory", "NumPyEigensolverFactory"]
