@@ -14,9 +14,11 @@
 
 from typing import Union, List
 
+from ..deprecation import DeprecatedType, warn_deprecated
+
 
 class WatsonHamiltonian:
-    """
+    """**DEPRECATED**
     Watson Hamiltonian class containing the results of a driver's anharmonic calculation
     """
 
@@ -26,6 +28,17 @@ class WatsonHamiltonian:
             data: Hamiltonian matrix elements
             num_modes: number of modes
         """
+        warn_deprecated(
+            "0.2.0",
+            DeprecatedType.CLASS,
+            "WatsonHamiltonian",
+            additional_msg=(
+                "Instead look towards the qiskit_nature.properties.second_quantization.vibrational "
+                "module. The new return object for drivers is the VibrationalStructureDriverResult "
+                "which you can construct from a WatsonHamiltonian via the "
+                "`from_legacy_driver_result()` method."
+            ),
+        )
         self._data = data
         self._num_modes = num_modes
 
